@@ -12,7 +12,7 @@ base_filename = os.path.join(template_dir, 'standard.tmpl')
 
 class SitePage(Servlet):
 
-    dispatcher = ActionDispatch()
+    dispatcher = ActionDispatch(default_action='default')
 
     def awake(self):
         Servlet.awake(self, call_setup=False)
